@@ -1,8 +1,9 @@
 from operator import __add__, __sub__
+import sys
 import pytest
 from whatever import _
 
-from funcy.py2 import map, merge_with
+from funcy import lmap, merge_with
 from funcy.funcs import *
 from funcy.seqs import keep
 
@@ -47,7 +48,7 @@ def test_curry():
 def test_curry_funcy():
     # curry() doesn't handle required star args,
     # but we can code inspection for funcy utils.
-    assert curry(map)(int)('123') == [1, 2, 3]
+    assert curry(lmap)(int)('123') == [1, 2, 3]
     assert curry(merge_with)(sum)({1: 1}) == {1: 1}
 
 def test_rcurry():
@@ -94,16 +95,41 @@ def test_autocurry_kwargs():
     assert at(b=3, c=9)(1) == (1, 3, 9)
     with pytest.raises(TypeError): at(b=2, d=3, e=4)(a=1, c=1)
 
+
+def test_autocurry_kwonly():
+    at = autocurry(lambda a, *, b: (a, b))
+    assert at(1, b=2) == (1, 2)
+    assert at(1)(b=2) == (1, 2)
+    assert at(b=2)(1) == (1, 2)
+
+    at = autocurry(lambda a, *, b=10: (a, b))
+    assert at(1) == (1, 10)
+    assert at(b=2)(1) == (1, 2)
+
+    at = autocurry(lambda a=1, *, b: (a, b))
+    assert at(b=2) == (1, 2)
+    assert at(0)(b=2) == (0, 2)
+
+    at = autocurry(lambda *, a=1, b: (a, b))
+    assert at(b=2) == (1, 2)
+    assert at(a=0)(b=2) == (0, 2)
+
+# TODO: move this here once we drop Python 3.7
+if sys.version_info >= (3, 8):
+    pytest.register_assert_rewrite("tests.py38_funcs")
+    from .py38_funcs import test_autocurry_posonly  # noqa
+
+
 def test_autocurry_builtin():
     assert autocurry(complex)(imag=1)(0) == 1j
-    assert autocurry(map)(_ + 1)([1, 2]) == [2, 3]
+    assert autocurry(lmap)(_ + 1)([1, 2]) == [2, 3]
     assert autocurry(int)(base=12)('100') == 144
-    # Only works in newer Pythons, relies on inspect.signature()
-    # assert autocurry(str.split)(sep='_')('a_1') == ['a', '1']
+    if sys.version_info >= (3, 7):
+        assert autocurry(str.split)(sep='_')('a_1') == ['a', '1']
 
 def test_autocurry_hard():
     def required_star(f, *seqs):
-        return map(f, *seqs)
+        return lmap(f, *seqs)
 
     assert autocurry(required_star)(__add__)('12', 'ab') == ['1a', '2b']
 
@@ -130,7 +156,6 @@ def test_autocurry_class():
     assert autocurry(int)(base=12)('100') == 144
 
 def test_autocurry_docstring():
-
     @autocurry
     def f(a, b):
         'docstring'
@@ -138,7 +163,6 @@ def test_autocurry_docstring():
     assert f.__doc__ == 'docstring'
 
 
-
 def test_compose():
     double = _ * 2
     inc    = _ + 1
@@ -162,15 +186,15 @@ def test_complement():
 
 def test_juxt():
     assert ljuxt(__add__, __sub__)(10, 2) == [12, 8]
-    assert map(ljuxt(_ + 1, _ - 1), [2, 3]) == [[3, 1], [4, 2]]
+    assert lmap(ljuxt(_ + 1, _ - 1), [2, 3]) == [[3, 1], [4, 2]]
 
 def test_iffy():
-    assert map(iffy(_ % 2, _ * 2, _ / 2), [1,2,3,4]) == [2,1,6,2]
-    assert map(iffy(_ % 2, _ * 2), [1,2,3,4]) == [2,2,6,4]
-    assert map(iffy(_ * 2), [21, '', None]) == [42, '', None]
-    assert map(iffy(_ % 2, _ * 2, None), [1,2,3,4]) == [2, None, 6, None]
-    assert map(iffy(_ + 1, default=1), [1, None, 2]) == [2, 1, 3]
-    assert map(iffy(set([1,4,5]), _ * 2), [1, 2, 3, 4]) == [2, 2, 3, 8]
-    assert map(iffy(r'\d+', str.upper), ['a2', 'c']) == ['A2', 'c']
-    assert map(iffy(set([1,4,5])), [False, 2, 4]) == [False, False, True]
-    assert map(iffy(None), [False, 2, 3, 4]) == [False, 2, 3, 4]
+    assert lmap(iffy(_ % 2, _ * 2, _ / 2), [1,2,3,4]) == [2,1,6,2]
+    assert lmap(iffy(_ % 2, _ * 2), [1,2,3,4]) == [2,2,6,4]
+    assert lmap(iffy(_ * 2), [21, '', None]) == [42, '', None]
+    assert lmap(iffy(_ % 2, _ * 2, None), [1,2,3,4]) == [2, None, 6, None]
+    assert lmap(iffy(_ + 1, default=1), [1, None, 2]) == [2, 1, 3]
+    assert lmap(iffy(set([1,4,5]), _ * 2), [1, 2, 3, 4]) == [2, 2, 3, 8]
+    assert lmap(iffy(r'\d+', str.upper), ['a2', 'c']) == ['A2', 'c']
+    assert lmap(iffy(set([1,4,5])), [False, 2, 4]) == [False, False, True]
+    assert lmap(iffy(None), [False, 2, 3, 4]) == [False, 2, 3, 4]
